==> xmonad-0.13-10-armv7h.pkg.tar.xz: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.13
id: xmonad-0.13-An4AfxTcjBLF9HpiWCVzwx
key: xmonad-0.13-An4AfxTcjBLF9HpiWCVzwx
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from
    the keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other
    extensions, may be written by the user in config files. Layouts are
    applied dynamically, and different layouts may be used on each
    workspace. Xinerama is fully supported, allowing windows to be tiled
    on several screens.
category: System
author: Spencer Janssen
exposed: True
indefinite: False
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
abi: 4417026188fc30638f3c1b400c8eba13
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xmonad-0.13
library-dirs: /usr/lib/ghc-8.2.2/site-local/xmonad-0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/xmonad
hs-libraries: HSxmonad-0.13-An4AfxTcjBLF9HpiWCVzwx
depends:
    base-4.10.1.0 containers-0.5.10.2
    data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65 directory-1.3.0.2
    extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF
    filepath-1.4.1.2 setlocale-1.0.0.5-8ARyg4Rug6W5voPz5AROBp
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH process-1.6.1.0 unix-2.7.2.2
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    X11-1.8-DlIbKHXc61G361OYDPKBX0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-default-0.7.1.1-FICujruwzSN8grhdf3Hr65=f057e993f72fa1f980dd728ed8010ca1
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF=ff98b9e1ba3a1bc553e70d357f632c01
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             setlocale-1.0.0.5-8ARyg4Rug6W5voPz5AROBp=c2d7d8b52a62dd5cd8e4c2fd40180167
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             X11-1.8-DlIbKHXc61G361OYDPKBX0=ea28abd200f80ee95f4a2c59c564f90a
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> xmonad-0.13-11-armv7h.pkg.tar.xz: usr/share/haskell/register/xmonad.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xmonad
version: 0.13
id: xmonad-0.13-E9je7XJKvxRFE8dOkBsrrT
key: xmonad-0.13-E9je7XJKvxRFE8dOkBsrrT
license: BSD3
maintainer: xmonad@haskell.org
homepage: http://xmonad.org
synopsis: A tiling window manager
description:
    xmonad is a tiling window manager for X. Windows are arranged
    automatically to tile the screen without gaps or overlap, maximising
    screen use. All features of the window manager are accessible from
    the keyboard: a mouse is strictly optional. xmonad is written and
    extensible in Haskell. Custom layout algorithms, and other
    extensions, may be written by the user in config files. Layouts are
    applied dynamically, and different layouts may be used on each
    workspace. Xinerama is fully supported, allowing windows to be tiled
    on several screens.
category: System
author: Spencer Janssen
exposed: True
indefinite: False
exposed-modules:
    XMonad XMonad.Config XMonad.Core XMonad.Layout XMonad.Main
    XMonad.ManageHook XMonad.Operations XMonad.StackSet
hidden-modules: Paths_xmonad
abi: 6dfbfc6b292bb505a3e714faf82ea29c
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/xmonad-0.13
library-dirs: /usr/lib/ghc-8.2.2/site-local/xmonad-0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/xmonad
hs-libraries: HSxmonad-0.13-E9je7XJKvxRFE8dOkBsrrT
depends:
    base-4.10.1.0 containers-0.5.10.2
    data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr directory-1.3.0.2
    extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF
    filepath-1.4.1.2 setlocale-1.0.0.5-8ARyg4Rug6W5voPz5AROBp
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH process-1.6.1.0 unix-2.7.2.2
    utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    X11-1.8-JnAOOA5ca1mBqz6w5LwuYT
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             data-default-0.7.1.1-AA4CT1Ft3yBIiqFbrFdPSr=0186e0f4b96bc201d2baef8ade597d90
             directory-1.3.0.2=7b913664ccd770192b307d7c4c6817cc
             extensible-exceptions-0.1.1.4-E1upJpu86CL5ydxQ3NbPRF=ff98b9e1ba3a1bc553e70d357f632c01
             filepath-1.4.1.2=a40cd48e5480796e558f3c29652ee19a
             setlocale-1.0.0.5-8ARyg4Rug6W5voPz5AROBp=c2d7d8b52a62dd5cd8e4c2fd40180167
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             process-1.6.1.0=e78440f24fd9cc3300a1da2a92a47757
             unix-2.7.2.2=3df01ca0d7640dab598065ff1b1cffeb
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             X11-1.8-JnAOOA5ca1mBqz6w5LwuYT=d42095e6df3db8f22e7846b4fbf85785
haddock-interfaces: /usr/share/doc/xmonad/html/xmonad.haddock
haddock-html: /usr/share/doc/xmonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
